@@ -773,16 +773,16 @@ inform_process_count(PCP_CONNECTION *frontend)
 
 	process_list = pool_get_process_list(&process_count);
 
-	mesg = (char *)palloc(6*process_count);	/* port# is at most 5 characters long (MAX:65535) */
+	mesg = (char *)palloc(7*process_count);	/* PID is at most 6 characters long */
 
 	snprintf(process_count_str, sizeof(process_count_str), "%d", process_count);
 
 	for (i = 0; i < process_count; i++)
 	{
-		char port[6];
-		snprintf(port, sizeof(port), "%d", process_list[i]);
-		snprintf(mesg+total_port_len, strlen(port)+1, "%s", port);
-		total_port_len += strlen(port)+1;
+		char process_id[7];
+		snprintf(process_id, sizeof(process_id), "%d", process_list[i]);
+		snprintf(mesg+total_port_len, strlen(process_id)+1, "%s", process_id);
+		total_port_len += strlen(process_id)+1;
 	}
 
 	pcp_write(frontend, "n", 1);
