@@ -71,7 +71,7 @@ wd_IP_up(void)
 		{
 			for (i = 0; i < WD_TRY_PING_AT_IPUP; i++)
 			{
-				if (!wd_is_unused_ip(pool_config->delegate_IP))
+				if (wd_is_ip_exists(pool_config->delegate_IP) == true)
 					break;
 				ereport(DEBUG1,
 					(errmsg("watchdog bringing up delegate IP"),
@@ -122,7 +122,7 @@ wd_IP_down(void)
 		{
 			for (i = 0; i < WD_TRY_PING_AT_IPDOWN; i++)
 			{
-				if (wd_is_unused_ip(pool_config->delegate_IP))
+				if (wd_is_ip_exists(pool_config->delegate_IP) == false)
 					break;
 			}
 
@@ -180,7 +180,6 @@ exec_ifconfig(char * path,char * command)
 	int pid, i = 0;
 	char* buf;
 	char *bp, *ep;
-	sighandler_t sig_org;
 
 	if (pipe(pfd) == -1)
 	{
@@ -219,11 +218,16 @@ exec_ifconfig(char * path,char * command)
 	}
 	args[i++] = NULL;
 
-	sig_org = signal(SIGCHLD, SIG_DFL);
-
 	pid = fork();
+	if (pid == -1)
+	{
+		ereport(FATAL,
+			(errmsg("failed to execute interface up/down command"),
+				 errdetail("fork() failed with reason: \"%s\"", strerror(errno))));
+	}
 	if (pid == 0)
 	{
+		on_exit_reset();
 		processType = PT_WATCHDOG_UTILITY;
 		close(STDOUT_FILENO);
 		dup2(pfd[1], STDOUT_FILENO);
@@ -238,17 +242,16 @@ exec_ifconfig(char * path,char * command)
 		for (;;)
 		{
 			int result;
-			result = wait(&status);
-			if (result < 0 && errno != ECHILD)
+			result = waitpid(pid, &status, 0);
+			if (result < 0)
 			{
 				if (errno == EINTR)
 					continue;
 
 				ereport(DEBUG1,
-					(errmsg("watchdog exec wait()failed"),
-						 errdetail("wait() system call failed with reason \"%s\"", strerror(errno))));
+					(errmsg("watchdog exec waitpid()failed"),
+						 errdetail("waitpid() system call failed with reason \"%s\"", strerror(errno))));
 
-				signal(SIGCHLD, sig_org);
 				return WD_NG;
 			}
 
@@ -258,7 +261,6 @@ exec_ifconfig(char * path,char * command)
 					(errmsg("watchdog exec ifconfig failed"),
 						errdetail("'%s' failed. exit status: %d",command, WEXITSTATUS(status))));
 
-				signal(SIGCHLD, sig_org);
 				return WD_NG;
 			}
 			else
@@ -269,7 +271,6 @@ exec_ifconfig(char * path,char * command)
 	ereport(DEBUG1,
 		(errmsg("watchdog exec ifconfig: '%s' succeeded", command)));
 
-	signal(SIGCHLD, sig_org);
 	return WD_OK;
 }
 
